@@ -95,18 +95,18 @@ class COCO:
         self.maxAnnId = 0
         self.maxImgId = 0
         if annotation_file is not None and osp.exists(annotation_file):
-            # print("loading annotations into memory...")
+            print("loading annotations into memory...")
             tic = time.time()
             dataset = json.load(open(annotation_file, "r"))
             assert type(dataset) == dict, "annotation file format {} not supported".format(
                 type(dataset)
             )
-            # print("Done (t={:0.2f}s)".format(time.time() - tic))
+            print("Done (t={:0.2f}s)".format(time.time() - tic))
             self.dataset = dataset
             self.createIndex()
-            # print(
-            #     f"load coco with {len(self.dataset['images'])} images and {len(self.dataset['annotations'])} annotations."
-            # )
+            print(
+                f"load coco with {len(self.dataset['images'])} images and {len(self.dataset['annotations'])} annotations."
+            )
 
     def hasImage(self, imageName):
         imgId = self.imgNameToId.get(imageName, None)
@@ -177,14 +177,15 @@ class COCO:
         id: int,
         name: str,
         color: list,
-        supercategory: str = "none",
+        supercategory: str = None,
     ):
         cat = {
             "id": id,
             "name": name,
             "color": color,
-            "supercategory": supercategory,
         }
+        if supercategory is not None:
+            cat["supercategory"] = supercategory
         self.cats[id] = cat
         self.dataset["categories"].append(cat)
 
@@ -255,6 +256,7 @@ class COCO:
         image_id: int,
         category_id: int,
         segmentation: list,
+        area: float = None,
         id: int = None,
         bbox: list = None,
     ):
@@ -272,10 +274,11 @@ class COCO:
             "iscrowd": 0,
             "image_id": image_id,
             "category_id": category_id,
-            "segmentation": [segmentation],
-            "area": self.getArea(segmentation) if len(segmentation) != 0 else bbox[2]* bbox[3],
+            "area": self.getArea(segmentation),
             "bbox": bbox,
         }
+        if segmentation is not None and len(segmentation) != 0:
+            ann['segmentation'] = segmentation
 
         self.dataset["annotations"].append(ann)
         self.anns[id] = ann
